ChatbotService class

Constructors

ChatbotService({required String apiKey, required String systemPrompt, double temperature = 0.7, int maxTokens = 4000, String model = 'gpt-3.5-turbo'})

Properties

apiKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
maxTokens → int
final
model → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt → String
final
temperature → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamMessages(String message) → Stream<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited